@@ -20,18 +20,14 @@ use Log::Fast;
 use Time::HiRes qw(time);
 use File::Basename;
 use Data::Dumper;
-
-our $THREADS = FALSE;
-eval {
-    use threads;
-    $THREADS = TRUE;
-};
+use Config;
+use threads;
 
 BEGIN {
     require Exporter;
 
     # set the version for version checking
-    our $VERSION = 1.13;
+    our $VERSION = 1.14;
 
     # Inherit from Exporter to export functions and variables
     our @ISA = qw(Exporter);
@@ -585,11 +581,11 @@ sub _send_to_logger {      # This actually simplifies the previous object ... se
     my $prefix = $self->{$level . '-PREFIX'} . '';    # A copy not a pointer
     my $forked = ($PARENT ne $$) ? 'C' : 'P';
     my $threaded = 'P--';
-    if ($THREADS) {
-        eval {
+    if ($Config{'useithreads'}) { # Do eval so non-threaded perl's don't whine
+        eval(q(
             my $tid = threads->tid();
             $threaded = ($tid > 0) ? sprintf('T%02',$tid) : 'P--';
-        };
+        ));
     }
 
     $prefix =~ s/\%PID\%/$$/g;
